==> fap-0.10.0.tar.bz2: fap-0.10.0/src/libs/fox-tray/win32/FXTrayApp.cpp <==
/*
FoxTray, system tray icon for the FOX Toolkit

Copyright (c) 2008, Hendrik Rittich
All rights reserved.

Redistribution and use in source and binary forms, with or without 
modification, are permitted provided that the following conditions are
met:

    * Redistributions of source code must retain the above copyright
      notice, this list of conditions and the following disclaimer.
    * Redistributions in binary form must reproduce the above copyright
      notice, this list of conditions and the following disclaimer in 
      the documentation and/or other materials provided with the 
      distribution.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/
#include "FXTrayApp.h"

#include "FXTrayIcon.h"

namespace FX {

FXIMPLEMENT(FXTrayApp, FXApp, NULL, 0);

FXTrayApp::FXTrayApp(const FXString& name, const FXString& vendor) :
    FXApp(name, vendor)
{

}

void FXTrayApp::create()
{
    FXApp::create();

    mTaskbarRestartId = RegisterWindowMessage(TEXT("TaskbarCreated"));
}


long FXTrayApp::dispatchEvent(FXID hwnd,unsigned int iMsg,unsigned int wParam,long lParam)
{
    // return true; // event dispached successful
    if (iMsg == mTaskbarRestartId)
    {
        FXWindow* wnd = findWindowWithId(hwnd);
        if (wnd && wnd->isMemberOf(&FXTrayIcon::metaClass) ) {
            static_cast<FXTrayIcon*>(wnd)->mapToManager();
        }

        return true;
    }

    return FXApp::dispatchEvent(hwnd, iMsg, wParam, lParam);
}

}

==> fap-0.11.1.tar.bz2: fap-0.11.1/src/libs/fox-tray/win32/FXTrayApp.cpp <==
/*
FoxTray, system tray icon for the FOX Toolkit

Copyright (c) 2008, Hendrik Rittich
All rights reserved.

Redistribution and use in source and binary forms, with or without 
modification, are permitted provided that the following conditions are
met:

    * Redistributions of source code must retain the above copyright
      notice, this list of conditions and the following disclaimer.
    * Redistributions in binary form must reproduce the above copyright
      notice, this list of conditions and the following disclaimer in 
      the documentation and/or other materials provided with the 
      distribution.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/
#include "FXTrayApp.h"

#include "FXTrayIcon.h"

namespace FX {

FXIMPLEMENT(FXTrayApp, FXApp, NULL, 0)

FXTrayApp::FXTrayApp(const FXString& name, const FXString& vendor) :
    FXApp(name, vendor)
{

}

void FXTrayApp::create()
{
    FXApp::create();

    mTaskbarRestartId = RegisterWindowMessage(TEXT("TaskbarCreated"));
}


long FXTrayApp::dispatchEvent(FXID hwnd,unsigned int iMsg,unsigned int wParam,long lParam)
{
    // return true; // event dispached successful
    if (iMsg == mTaskbarRestartId)
    {
        FXWindow* wnd = findWindowWithId(hwnd);
        if (wnd && wnd->isMemberOf(&FXTrayIcon::metaClass) ) {
            static_cast<FXTrayIcon*>(wnd)->mapToManager();
        }

        return true;
    }

    return FXApp::dispatchEvent(hwnd, iMsg, wParam, lParam);
}

}
